@@ -237,7 +237,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         qc_id = response.json()["id"]
 
-        preview_url = self.smart_insight_url + "/composed_queries/" + qc_id + "/preview"
+        preview_url = self.smart_insight_url + "/composed_queries/" + qc_id + "/preview?agentId="+self._agentId
 
         s = requests.Session()
         s.keep_alive = False
