@@ -398,7 +398,7 @@ class Insight_Definition:
 
         qc = self.get_component(query)
 
-        url_preview = self.smart_insight_url+"/composed_queries/"+qc["settings"]["qc"]+"/preview?limit=100"
+        url_preview = self.smart_insight_url+"/composed_queries/"+qc["settings"]["qc"]+"/preview?limit=100&agentId="+self.agent_id
 
         s = requests.Session()
         s.keep_alive = False
@@ -1165,7 +1165,7 @@ class Insight_Definition:
 
         query_composer = r["qc"]
 
-        url_preview = self.smart_insight_url+"/composed_queries/"+query_composer["id"]+"/preview?limit=100"
+        url_preview = self.smart_insight_url+"/composed_queries/"+query_composer["id"]+"/preview?limit=100?&agentId="+self.agent_id
 
         s = requests.Session()
         s.keep_alive = False
